@@ -1,8 +1,6 @@
-import random
 from itertools import groupby
 from typing import Optional
 
-import funcy as fn
 from dfa import dict2dfa, DFA
 from pysat.solvers import Glucose4
 
@@ -17,8 +15,6 @@ from dfa_identify.encoding import (
 
 def extract_dfa(codec: Codec, apta: APTA, model: list[int]) -> DFA:
     # Fill in don't cares in model.
-    n_tokens = len(apta.alphabet)
-
     decoded = map(codec.decode, model)
     decoded = list(decoded)
     var_groups = groupby(decoded, type)
@@ -26,7 +22,7 @@ def extract_dfa(codec: Codec, apta: APTA, model: list[int]) -> DFA:
     group1 = next(var_groups)
     assert group1[0] == ColorAcceptingVar
     accepting = {v.color for v in group1[1] if v.true}
-    
+
     group2 = next(var_groups)
     assert group2[0] == ColorNodeVar
 
@@ -52,15 +48,27 @@ def extract_dfa(codec: Codec, apta: APTA, model: list[int]) -> DFA:
         char = token2char[var.token]
         assert char not in char2node
         char2node[char] = var.node_color
-        
+
     return dict2dfa(dfa_dict, start=node2color[0])
 
 
 def find_dfa(
-        accepting: list[Word], 
+        accepting: list[Word],
         rejecting: list[Word],
-        solver_fact=Glucose4, 
+        solver_fact=Glucose4,
 ) -> Optional[DFA]:
+    """Finds a minimal dfa that is consistent with the labeled examples.
+
+    Inputs:
+      - accepting: A sequence of "words" to be accepted.
+      - rejecting: A sequence of "words" to be rejected.
+      - solver: A py-sat API compatible object for solving CNF SAT queries.
+
+    Returns:
+      Either a DFA consistent with accepting and rejecting or None
+      indicating that no DFA exists.
+    """
+
     apta = APTA.from_examples(accepting=accepting, rejecting=rejecting)
     for codec, clauses in dfa_id_encodings(apta):
         with solver_fact() as solver:
@@ -70,4 +78,6 @@ def find_dfa(
             if solver.solve():
                 model = solver.get_model()
                 return extract_dfa(codec, apta, model)
-                return model
+
+
+__all__ = ['find_dfa', 'extract_dfa']
